Module format

Module format 

Format Root values to JSONC or pretty/compact JSON.

Structs

Options
Options represents the customizations that can be made when formatting.

Functions

write_json_compact
Serializes/formats the provided JSON Root value to the writer as valid JSON.
write_json_compact_iter
Serializes/formats the provided Iterator of ScanResults to the writer.
write_jsonc
Serializes/formats the provided JSON Root value to the writer as “jsonc”.
write_jsonc_opts
Serializes/formats the provided JSON Root value to the writer as “jsonc” using the formatting options.