pub struct Options<'a> { /* private fields */ }Expand description
Options represents the customizations that can be made when formatting.
Implementations
Sourceimpl<'a> Options<'a>
impl<'a> Options<'a>
Sourcepub fn with_indent(self, s: &'a str) -> Self
pub fn with_indent(self, s: &'a str) -> Self
Sets the indent to the provided string. The default is two spaces.
Sourcepub fn with_line_length(self, n: usize) -> Self
pub fn with_line_length(self, n: usize) -> Self
Sets the line length that objects and arrays will wrap on. The default is 80 characters.
Sourcepub fn with_max_object_pairs_per_line(self, n: usize) -> Self
pub fn with_max_object_pairs_per_line(self, n: usize) -> Self
Sets the maximum number of object key/value pairs that can appear on the same line. The default is 1.
Sourcepub fn with_max_array_values_per_line(self, n: usize) -> Self
pub fn with_max_array_values_per_line(self, n: usize) -> Self
Sets the maximum number of array values that can appear on the same line. The default is 4.