Format Root values to JSONC or pretty/compact JSON.
Structs
- Options
- Options represents the customizations that can be made when formatting.
Functions
- write_
json_ compact - Serializes/formats the provided JSON Root value to the writer as valid JSON.
- write_
json_ compact_ iter - Serializes/formats the provided
Iteratorof ScanResults to the writer. - write_
jsonc - Serializes/formats the provided JSON Root value to the writer as “jsonc”.
- write_
jsonc_ opts - Serializes/formats the provided JSON Root value to the writer as “jsonc” using the formatting options.